# A class to manage notifications
import re
import utils.adb_read_icon_db as adb_read_icon_db


class Notificaton:
    def __init__(self, raw_notification):
        
        self.notification_keys = ["key",
                                "pri",
                                "opPkg",
                                "when",
                                "tickerText",
                                "android.title",
                                "android.subText",
                                "android.bigText",
                                "icon"]

        self.known_package_names = {"com.android.messaging" : "Messaging",
                                    "com.spotify.music" : "Spotify",
                                    "com.nordvpn.android" : "NordVPN"}

        self.attributes = {}

        self.icon_path = "adb_icons/"

        self.parse_notification(raw_notification)

    def check_null(self, value):
        # Converts null to none if it exists
        if value != "null":
            return value

        return None

    def get_icon(self, pkg, icon_db_path):
        return adb_read_icon_db.readBlobData(pkg, icon_db_path)

    def get_notification_value(self, line):
        if "=" in line:

            # Parse the line to pull the values from the notification dump
            search = re.search('=(.*)\n', line + "\n")
            if search:
                value = search.group(1)

                # Toss out any typing
                if "String (" in value or "SpannableString (" in value or "Icon(" in value:
                    value = re.search('\((.*)\)', value).group(1)
                    
                    if "&^&" in value:
                        value = value.replace("&^&", "\n")
                   

                # Give a null check & send it off!
                return self.check_null(value)       

    def parse_notification(self, raw_notification):
        all_attributes = raw_notification.split("\n")

        iter = 0
        for attribute in all_attributes:
            attribute = attribute.strip()

            for key in self.notification_keys:

                # Iterate through keys and put values...
                if attribute.startswith(key):
                    if key == "android.bigText":
                        # Big text is multi-lined
                        line_count = 1
                        for line in all_attributes[iter:]:
                            if line[-1] == ")":
                                break
                            line_count += 1
                        
                        # Uses " &&" as a newline sequence because the newline char is filtered out later. 
                        attribute = "" + "&^&".join(all_attributes[iter:iter + line_count])

                        iter += line_count

                    
                    # and keep all notification attributes in a dictionary
                    self.attributes.update({key : self.get_notification_value(attribute)})
            
            iter += 1

        if self.attributes.get("icon"):
            self.attributes.update({"icon_path" : self.get_icon(self.attributes.get("opPkg"), "app_icons.db")})
            
            




# TODO: Should the function just set 

from utils.bt_track import Track
from dbus.mainloop.glib import DBusGMainLoop    # Handling the DBus event based loop
from gi.repository import GLib                  # Handling the DBus event based loop
from time import sleep
import dbus
import threading
import logging


class BluetoothManager:
    def __init__(self):
        # Initialize the logger
        self.log = logging.getLogger()

        # Temp variable for the DBus Bluetooth player interface
        self.bt_player_iface = None  

        # General Info Variables
        self.connected = False
        self.device_name = None
        self.device_addr = None
        self.volume = None

        # Track Variables
        self.track_info = None


########## Utility/Info Getting Methods ##########

    def get_conn_device(self):
        for path, ifaces in self.mgr.GetManagedObjects().items():
            if "org.bluez.Device1" in str(ifaces):          
                # Check for device connecton, set name if connected.
                if ifaces["org.bluez.Device1"]["Connected"]:
                    self.log.debug(str(ifaces["org.bluez.Device1"]))                                             
                    self.device_name = ifaces["org.bluez.Device1"]["Name"]
                    self.device_addr = ifaces["org.bluez.Device1"]["Address"]
                    self.log.info("Bluetooth device: " + self.device_name + " connected with MAC address of " + self.device_addr + ".")
                    self.connected = True


    # Get the status of the current track (paused, playing)
    def get_track_status(self):
        self.status = self.track.status


    # Sets a dict object with all track metadata contained in it.
    def get_track_data(self):

        # If there's no active track playing, Sets none.
        if not self.track.active_track or not self.track:
            self.track_info = {
            "title" : None,
            "artist" : None,
            "album" : None,
            "duration" : None,
            "position" : None
            }

        else:
            self.track_info = {
            "title" : self.track.title,
            "artist" : self.track.artist,
            "album" : self.track.album,
            "duration" : self.track.duration,
            "position" : self.track.position  
            }

        # Update the status of the track
        self.get_track_status()


########## Signal Reciever Methods ##########

    def iface_added(self, path, iface):
        if "org.bluez.MediaTransport1" in str(iface):
            transport_mgr = iface["org.bluez.MediaTransport1"]
            self.volume = transport_mgr["Volume"]

        elif "org.bluez.MediaPlayer1" in str(iface):
            player_mgr = iface["org.bluez.MediaPlayer1"]
            self.position = player_mgr["Position"]

        if not self.connected:
            # If a device isn't already connected, changed the connected status and get the device name
            self.connected = True
            self.get_conn_device()
        

    def iface_removed(self, path, iface):
        self.connected = False


    def prop_changed(self, iface, changed, invalidated):
        # TODO: Sync volume control here, seems to be an update field.
        if "Title" in str(changed.items()):
            if "org.bluez.MediaPlayer1" in str(iface):
                self.log.debug("Track properties updated: " + str(changed.items()))
                self.track = Track(self.mgr) 
                self.track.get_track(changed)
                self.get_track_data()


########## Main Methods ########## 

    def bluetooth_manager(self):
        # Start the main loop
        DBusGMainLoop(set_as_default=True)

        # Initialize DBus interface to read from
        self.bus = dbus.SystemBus()

        # Create the object manager
        self.mgr = dbus.Interface(self.bus.get_object("org.bluez", "/"), 'org.freedesktop.DBus.ObjectManager')

        # Initialize the Track object
        self.track = Track(self.mgr)

        # Create a receiver to monitor for a newly connected device
        self.bus.add_signal_receiver(
            self.iface_added, 
            signal_name='InterfacesAdded', 
            dbus_interface="org.freedesktop.DBus.ObjectManager", 
            bus_name="org.bluez")

        # Create a receiver to monitor for a disconnected device
        self.bus.add_signal_receiver(
            self.iface_removed, 
            signal_name='InterfacesRemoved', 
            dbus_interface="org.freedesktop.DBus.ObjectManager", 
            bus_name="org.bluez")

        # Create a reciever to monitor song changes
        self.bus.add_signal_receiver(
            self.prop_changed,
            signal_name='PropertiesChanged',
            dbus_interface='org.freedesktop.DBus.Properties',
            bus_name='org.bluez')

        self.get_conn_device()
        
            
        GLib.MainLoop().run()
    
    # Implements controls such as pause, play, skip, back, etc...
    def bluetooth_ctl(self, control):
        for path, ifaces in self.mgr.GetManagedObjects().items():
            if "org.bluez.MediaPlayer1" in str(ifaces):  
                player_iface = dbus.Interface(self.bus.get_object('org.bluez', path), 'org.bluez.MediaPlayer1')

                # A dictionary of controls and their corresponding method calls
                controls = {
                    "play" : player_iface.Play,
                    "pause" : player_iface.Pause,
                    "next" : player_iface.Next,
                    "prev" : player_iface.Previous
                }

                # Do the control specified by parameter via the dict
                controls[control]()


    def run(self):
        metaThr = threading.Thread(target=self.bluetooth_manager, name = 'bluetooth_manager', daemon=True)
        metaThr.start()


if __name__ == "__main__":
    # Testing of the bt_ctl & bt_track class.

    newBlue = BluetoothManager()
    newBlue.run()
    
    def main():

        # A delay is neccesary to allow the threads to start and initialize the dbus object manager.
        sleep(0.01)

        newBlue.get_track_data()

        track = newBlue.track_info
        status = newBlue.status

        if newBlue.track_info:
            for key in newBlue.track_info.keys():
                print(key.capitalize() + " : " + str(newBlue.track_info[key]))
                track = newBlue.track_info
            print("-" * 32)

        while True:
            if newBlue.track_info != track:
                for key in newBlue.track_info.keys():
                    print(key.capitalize() + " : " + str(newBlue.track_info[key]))
                    track = newBlue.track_info
                print("-" * 32)

            if newBlue.status != status:
                print("Status : " + status)
                status = newBlue.status
                print("-" * 32)
        
            sleep(0.01)

    mainThr = threading.Thread(target=main, name = 'main', daemon=True)
    mainThr.start()

    sleep(0.5)

    # Loop to add control of the track. Sleep is neccesary to allow track status to update
    while True:
        print("Command Input")
        command = input("Command:")
        newBlue.bluetooth_ctl(command)
        sleep(.5)
        print(("*" * 8) + newBlue.status)



# Tested with the ELM27-emulator package: https://github.com/Ircama/ELM327-emulator

import glob
import logging
import os
import threading
import time
import obd
from pint import UnitRegistry

class CarInfo:
    def __init__(self, port=None):

        # Set logger
        self.log = logging.getLogger()

        # Initial vars
        self.user_port = port
        self.port = None
        self.connected = False


    # TODO: the OBD.Async() should be implemented here.
    def get_command(self, command):
        self.check_connection()
        if self.connected:
            command_list = {
                "speed" : obd.commands.SPEED,
                "fuel_level" : obd.commands.FUEL_LEVEL,
                "voltage" : obd.commands.CONTROL_MODULE_VOLTAGE,
                "rpm" : obd.commands.RPM,
                "eng_load" : obd.commands.ENGINE_LOAD,
                "dtc" : obd.commands.GET_DTC
            }

            if command_list.get(command):
                response = self.connection.query(command_list.get(command))

                # Determine if value is numerical (Pint Quantity)
                quantity_type = UnitRegistry().Quantity
                if str(type(response.value)) == str(quantity_type):     # TODO: Fix this jenky solution
                    return response.value.magnitude
                
                # If type is not Pint Quantity, just return the value.
                return response.value

        # If not connected or value not found in dict, return None
        return None

    def check_connection(self):
        self.connected = (self.connection.status() == obd.OBDStatus.CAR_CONNECTED)
        return self.connected

    def try_connection(self, ports):
        for port in ports:
            self.log.debug("Attempting ELM connection to port: " + port)
            connection = obd.OBD(portstr=port, timeout=0.05)
            if connection.is_connected():
                return connection
    
        return None

    # Connection management loop for the OBDII functionality
    def obd_manager(self):
        path_warned = False
        while True:
            while not self.connected:
                if self.user_port:
                    # Check the user specified port for a connection
                    if os.path.exists(self.user_port):
                        self.port = self.user_port
                        # Initialize the OBDII connection
                        self.connection = obd.OBD(self.port)
                        time.sleep(0.2)
                        self.check_connection()
                    else:
                        if not path_warned:
                            self.log.warn("ODBII path: " + self.port + " does not exist.")
                            path_warned = True
                        time.sleep(0.2)
                else:
                    # Check all availible serial ports for connection if some are available, otherwise check the pts for the ELM emmulator.
                    if len(obd.scan_serial()) > 0:
                        ports = obd.scan_serial()
                        find_connection = self.try_connection(ports)
                        if find_connection:
                            self.connection = find_connection
                            self.check_connection()

                    elif len(glob.glob('/dev/pts/[0-9]*')) > 0:
                        ports = glob.glob('/dev/pts/[0-9]*')
                        find_connection = self.try_connection(ports)
                        if find_connection:
                            self.connection = find_connection
                            self.check_connection()

            path_warned = False
            time.sleep(1)

    def run(self):
        obd_thread = threading.Thread(target=self.obd_manager, name = 'obd_manager', daemon=True)
        obd_thread.start()

if __name__ == "__main__":
    carInfo = CarInfo("/dev/pts/2")
    if carInfo.connected:
        print("Connection to car established!")
        print("Speed:  \t", carInfo.get_command("speed"))
        # TODO: Fuel Level not supported?
        # print("Fuel:   \t", carInfo.get_command("fuel_level"))
        print("Voltage:\t", carInfo.get_command("voltage"))
        print("RPM:    \t", carInfo.get_command("rpm"))
        print("Eng Load:\t", carInfo.get_command("eng_load"))
        print("DTC:    \t", carInfo.get_command("dtc"))
    



# RESTful naming conventions https://restfulapi.net/resource-naming/

from flask import Flask, jsonify, render_template
from utils import adb_manager
from utils import bt_ctl, sys_utils, obd_info
from time import sleep
import logging


# TODO: Make logging level dynamic and cleaner
logging.basicConfig(level=logging.DEBUG)
log = logging.getLogger()

# Initialize the bluetooth controller
bt_man = bt_ctl.BluetoothManager()
bt_man.run()    

# Initialize the OBDII controller
# TODO: Create config options to specify the port.
car_man = obd_info.CarInfo()
car_man.run()

# Initialize the android debug bus controller
adb_man = adb_manager.AndroidManager()
adb_man.run()

# Initialize the app object and set the static/templates folders
# TODO: Make this class based
app = Flask(__name__, static_folder="web/static", template_folder="web/templates")
app.logger.setLevel(logging.ERROR)


""" 
==================
UI HTML Page
================== 
"""

# Returns the main landing page of PILOT
@app.route("/", methods=["GET"])
def home():
    return render_template("home.html")


"""
==================
System methods
==================
"""

# The time getting function to keep PILOT's clock realtively on par
# TODO: Better method of implementation? This is inacurate to about a half minute.
@app.route("/get-cpuload", methods=["POST"])
def get_cpuload():
    return jsonify({"cpu" : sys_utils.get_cpu_state() + "%"})


# Return the system hostname
@app.route("/get-hostname", methods=["POST"])
def get_hostname():
    return jsonify({"hostname" : sys_utils.get_hostname()})


"""
==================
Bluetooth methods
================== 
"""

# Gets the track information, returns track metadata and status in a JSON string.
@app.route("/bt-info", methods=["POST"])
def music_info():
    if bt_man.connected:
        # Get all track data
        bt_man.get_track_data()
        if bt_man.track_info:
            track_info = bt_man.track_info
        else:
            track_info = None

        # Get track playback status
        bt_man.get_track_status()
        if bt_man.status:
            track_status = bt_man.status
        else:
            track_status = None
        
        return jsonify({"btInfo" : {"connected" : bt_man.connected,
                                    "connectedDevice" : {"name" : bt_man.device_name, "address" : bt_man.device_addr},
                                    "track" : {"metadata" : track_info, "status" : track_status}}})

    # If conditionals are False, return a null value
    return jsonify({"btInfo" : {"connected" : bt_man.connected}})


# Deals with track control. Valid commands are "prev", "next", or "playback-change"
# TODO: Remove returns
@app.route("/bt-ctl/track-ctl/<command>", methods=["POST"])
def prev_track(command):
    if bt_man.connected:
        if command == "prev" or command =="next":
            bt_man.bluetooth_ctl(command)
            
            # Delay and return full track info
            sleep(0.5)

        elif command == "playback-change":
            # A little logic to change the state to the opposite of what it currently is
            if bt_man.status == "playing":
                bt_man.bluetooth_ctl("pause")
                bt_man.status = "paused"
            elif bt_man.status == "paused":
                bt_man.bluetooth_ctl("play")
                bt_man.status = "playing"

            return jsonify({"track" : {"status" : bt_man.status}})

    # If conditionals are False, return a null value
    return jsonify({"connected" : bt_man.connected})



""" 
==================
Vehicle methods
================== 
"""

# The car command endpoint, uses conditionals to determine how the values need to be manipulated
# TODO: Should this have individual endpoints? Seems convoluted
@app.route("/vehicle-info", methods=["POST"])
def car_command():
    if car_man.connected:

        try:
            # Conditionals to check what command was used 
            speed = round(car_man.get_command("speed"), 2)
            # TODO: Fix this, temporary as emmulator doesn't support gas
            # fuel_level = round(car_man.get_command("fuel_level"), 2)
            fuel_level = 56
            voltage = round(car_man.get_command("voltage"), 2)
            rpm = car_man.get_command("rpm")
            eng_load = car_man.get_command("eng_load")
            dtc = car_man.get_command("dtc")

        except TypeError:
            return jsonify({"vehicleInfo" : None})

        return jsonify({"vehicleInfo" : {"connection" : car_man.connected,
                                        "speed" : speed, 
                                        "fuelLevel" : fuel_level, 
                                        "voltage" : voltage, 
                                        "rpm" : rpm, 
                                        "engLoad" : eng_load,
                                        "dtc" : dtc}})

    return jsonify({"vehicleInfo" : {"connection" : car_man.connected}})

""" 
==================
ADB methods
================== 
"""
@app.route("/adb-info", methods=["POST"])
def get_adb():
    if adb_man.connected:
        return jsonify ({"android" : {
                            "connection" : adb_man.connected,
                            "notifications" : adb_man.get_notifications(), 
                            "battery" : adb_man.get_battery_level(),
                            "hostname" : adb_man.device_name,
                            "macAddr" : adb_man.bt_addr}})
    
    return jsonify({"android" : {
                        "connection" : adb_man.connected}})


    

def main():
    log.info("Starting Flask Application...")
    app.run(host="0.0.0.0", port=5000)

# Run the Application
if __name__ == "__main__":
    main()


import logging
import re
import subprocess
import threading
import time

from utils.adb_notification import Notificaton


class AndroidManager:
    def __init__(self):

        # Initial var declarations
        self.log = logging.getLogger()
        self.connected = None
        self.device_name = None
        self.bt_mac = None
        self.notifications = []


        # Initialize ADB
        run_adb_root = "adb root"
        run_root = subprocess.getoutput(run_adb_root)


    # This should run in a thread to update on the side
    def get_notifications(self):
        self.notifications = []

        notif_icon_path = "/data/data/com.android.launcher3/databases/app_icons.db"
        pull_db_cmd = "adb pull " + notif_icon_path

        notif_dump_cmd = "adb shell dumpsys notification --noredact"

        # Get the icon database off the phone
        subprocess.getoutput(pull_db_cmd)

        # Dump the notifications
        notif_dump = subprocess.getoutput(notif_dump_cmd)


        # Prune the list to get only the notifications
        # TODO: Clean this up if possible
        notif_list = notif_dump.split("NotificationRecord(")
        finalNotif = notif_list[len(notif_list) - 1].split("mAdjustments=[]")[0]
        notif_list[len(notif_list) - 1] = finalNotif
        notif_list.pop(0)

        for raw_notification in notif_list:
            new_notification = Notificaton(raw_notification)
            key = new_notification.attributes.get("key").split("|")[4]
            if key:
                self.notifications.append(new_notification.attributes)
        
        # Sort notifications by priority. The highest priority will appear at the top of the JSON.
        self.notifications.sort(reverse=True, key=self.sort_by_priority)
        
        return self.notifications


    # Method to get the battery level of the connected device
    def get_battery_level(self):
        dump_battery_cmd = "adb shell dumpsys battery"

        battery_dump = subprocess.getoutput(dump_battery_cmd)
        self.battery_level = int(re.search("level: (.*)\n", battery_dump).group(1))

        return self.battery_level
        

    # Pull hostname and mac address to compare in the web interface
    def get_bt_info(self):
        device_name_cmd = "adb shell settings get secure bluetooth_name"
        mac_addr_cmd = "adb shell settings get secure bluetooth_address"

        self.device_name = subprocess.getoutput(device_name_cmd)
        self.bt_addr = subprocess.getoutput(mac_addr_cmd)

        return [self.device_name, self.bt_addr]


    # Method to sort the notifications by priority
    def sort_by_priority(self, notification):
        return (notification.get("pri"))


    # Method to constantly check the state of the ADB connection
    def check_connection(self):
        check_connection_cmd = "adb get-state"
        connection_status = subprocess.getoutput(check_connection_cmd)
        if connection_status == "device":
            self.connected = True
        else:
            if self.connected == None or self.connected:
                self.log.error("ADB Device disconnected: " + subprocess.getoutput(check_connection_cmd))
            self.connected = False

        return self.connected


    # Manages the ADB connection, listens for a new connection
    def android_manager(self):
        self.log.debug("ADB Manager Started.")
        while True:
            while not self.connected:
                time.sleep(0.2)
                self.check_connection()

            if not self.device_name:
                self.get_bt_info()
                self.log.debug("ADB Device: " + self.device_name + " connected!")
            
            self.check_connection()
            time.sleep(0.5)


    # Starts the manager thread to monitor the connection
    def run(self):
        adb_thread = threading.Thread(target=self.android_manager, name = 'adb_manager', daemon=True)
        adb_thread.start()





# https://pynative.com/python-sqlite-blob-insert-and-retrieve-digital-data/

import sqlite3
import os
import logging

log = logging.getLogger()

sqliteConnection = False

def writeToFile(data, icon_dir_path, icon_name):
    # Check that the path specified exists, if not, create it
    if not os.path.isdir(icon_dir_path):
        os.makedirs(icon_dir_path)
    
    # Write icon file from SQL Blob
    log.debug('Attempting to save ' + icon_name)
    with open(icon_dir_path + icon_name, 'wb') as notif_icon:
        if not data == None:
            notif_icon.write(data)
            log.debug('BLOB data stored into: ' + icon_dir_path + icon_name)


def findPkgVal(cursor, pkg):
    table_iter = 0
    comp_names = cursor.execute("SELECT componentName FROM icons")
    for item in comp_names:
        comp_name = ''.join(item)
        if comp_name.startswith(pkg):
            return comp_name
    
def readBlobData(pkg, db_path):
    try:
        sqliteConnection = sqlite3.connect(db_path)
        cursor = sqliteConnection.cursor()
        log.debug("Connected to SQLite")

        compName = findPkgVal(cursor, pkg)
        if not compName == None:
            sql_fetch_blob_query = """SELECT * from icons where componentName = ?"""
            cursor.execute(sql_fetch_blob_query, (compName,))
            record = cursor.fetchall()
            for row in record:
                name = row[6]
                photo = row[4]
                photo_dir_path = "src/web/static/icons/adb_icons/"
                photo_name =  name + ".png"
                writeToFile(photo, photo_dir_path, photo_name)

            cursor.close()
        else:
            return None
        return "static/icons/adb_icons/" + photo_name

    except sqlite3.Error as error:
        log.error("Failed to read blob data from sqlite table", error)
    finally:
        if sqliteConnection:
            sqliteConnection.close()
            log.debug("sqlite connection is closed")

if __name__ == "__main__":
    readBlobData("com.android.contacts", "app_icons.db")



import logging
from dbus.exceptions import DBusException

class Track:
    def __init__(self, mgr):
        self.log = logging.getLogger()

        self.track_obj = {"Track" : None}

        try:
            # Create the initial track object to be used to get info on the track
            for path, iface in mgr.GetManagedObjects().items():
                if "org.bluez.MediaPlayer1" in str(iface):
                    self.track_obj = iface.get("org.bluez.MediaPlayer1")

            self.active_track = False
            self.status = "paused"

            # Set all needed values to be able to pull track metadata when class is instantiated.
            self.get_track()

            if self.active_track:
                self.get_status()
                self.get_position()
        except DBusException as e:
            self.log.error(e)


    def get_track(self, prop_update=None):
        if prop_update:
            self.track_obj = prop_update
        
        track = self.track_obj.get("Track")


        # Confirm the track is not empty (track == None)
        if track:
            print("TRACK: " + str(track))
            try:
                if track.get("Title"):
                # Title formatting, covering all my bases to make sure the title stays on one line (damn features!)
                    if len(track.get("Title")) > 34 and ("feat" in track.get("Title").lower() or "ft" in track.get("Title").lower()):
                        split_char = None
                        if "(" in track.get("Title"):
                            split_char = "("
                        elif "[" in track.get("Title"):
                            split_char = "["
                        elif "{" in track.get("Title"):
                            split_char = "{"
                        else:
                            if "FEAT" in track.get("Title"):
                                split_char = "FEAT"
                            if "feat" in track.get("Title"):
                                split_char = "feat"
                        
                        if split_char:
                            self.title = track.get("Title").split(split_char)[0]
                        else:
                            self.title = track.get("Title")

                    else:
                        self.title = track.get("Title")
                
                else:
                    self.title = track.get("Title")

                if track.get("Album"):
                # Album formatting, covering all my bases to make sure the Album stays on one line (damn features!)
                    if len(track.get("Album")) > 34 and ("feat" in track.get("Album").lower() or "ft" in track.get("Album").lower()):
                        split_char = None
                        if "(" in track.get("Album"):
                            split_char = "("
                        elif "[" in track.get("Album"):
                            split_char = "["
                        elif "{" in track.get("Album"):
                            split_char = "{"
                        else:
                            if "FEAT" in track.get("Album"):
                                split_char = "FEAT"
                            if "feat" in track.get("Album"):
                                split_char = "feat"
                        
                        if split_char:
                            self.album = track.get("Album").split(split_char)[0]
                        else:
                            self.album = track.get("Album")
                        
                    else:
                        self.album = track.get("Album")
                
                else:
                    self.album = track.get("Album")
                    
                self.duration = track.get("Duration")
                self.artist = track.get("Artist")
                self.active_track = True
            except KeyError as e:
                self.log.error("Key Error returned from bt_track.py:", e)

        else:
            self.active_track = False

    def get_status(self):
        self.status = self.track_obj.get("Status")

    def get_position(self):
        self.position = self.track_obj.get("Position")


from setuptools import setup, find_packages

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name="pilot-drive",
    version="0.0.1",
    author="Wesley Appler",
    author_email="wes@lamemakes.com",
    description="PILOT Auto is a modular vehicle head unit built in Python",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/lamemakes/pilot-auto",
    project_urls={
        "Bug Tracker": "https://github.com/lamemakes/pilot-auto/issues",
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Operating System :: Unix",
    ],
    install_requires=["flask", "obd"],
    package_data={"pilot-drive": ["src/web/*", "tests/*"]},
    packages=find_packages(include=["src", "src.*"]),
    #entry_points={'console_scripts' : ["pilot-drive=pilot-drive.main:main"]},
    python_requires=">=3.6",
)